.. raw:: html
   :file: fork.html

.. include:: definitions.txt

.. py:currentmodule:: quickapp

QuickApp
=============

|QuickApp| is a generic Python package that ....

**Motivation**: The purpose of |QuickApp| is **not** ....


Simple usage example: ::
  
      from quickapp import function
      
      function(1,2,3)
      
**News**

- 2012-11-18: Version 0.2 released (:ref:`changelog <changelog>`).

**Project status:** |QuickApp| is very well tested and documented.

**Support**: use the GitHub issue tracker_ or email me_.

**Documentation index**

- :ref:`installation` 
- :ref:`api` 
- :ref:`api_reference`
- :ref:`credits`


.. _tracker: http://github.com/AndreaCensi/quickapp/issues

.. _me: http://purl.org/censi/web


.. _installation:

Installation
------------

Install |QuickApp| using: ::

    $ pip install QuickApp
    
.. raw:: html
   :file: download.html

TYou can download this project in either zip_ or tar_ formats, or 
download using git: ::

    $ git clone git://github.com:AndreaCensi/quickappS.git

Install using: ::

    $ python setup.py develop
    $ nosetests -w src         # run the extensive test suite


.. _tar:: http://github.com/AndreaCensi/quickapp/tarball/master
.. _zip:: http://github.com/AndreaCensi/quickapp/zipball/master


.. include:: api.rst.inc


 

